/// <reference types="node" />
/// <reference types="jszip" />
import * as JSZip from 'jszip';
export declare type FileBuffer = ArrayBuffer | Buffer;
export declare type IncomingFile = File | Blob | FileBuffer;
export declare type IncomingFileContent = Uint8Array | Buffer;
export declare type FileType = 'document' | 'presentation' | 'spreadsheet' | 'drawing' | 'image';
export interface FileInformation {
    fileBuffer: FileBuffer;
    fileContent: IncomingFileContent;
}
export interface ArchiveEntry extends JSZipObject {
    [key: string]: any;
}
export interface Archive extends JSZip {
    files: {
        [key: string]: ArchiveEntry;
    };
    [key: string]: any;
}
export declare type ArchiveEntrySerialization = Serialization;
export interface FileMetaInformation {
    fileType: FileType;
    mimeType: string;
    name: string;
    size: number;
    creator: string;
    createdAt: string;
    modifiedAt: string;
    [key: string]: any;
}
export interface FileContent {
    [key: string]: any;
}
export interface FileMediaInformation {
    [key: string]: FileMedia;
}
export interface FileMedia {
    type: string;
    dataURI: string;
}
export declare class File {
    meta: FileMetaInformation;
    content: FileContent;
    media: FileMediaInformation;
    constructor(props: {
        content: FileContent;
        meta: FileMetaInformation;
        media: FileMediaInformation;
    });
}
export declare function readArchive(fileContent: IncomingFileContent): Promise<Archive>;
export interface ReadParams {
    file: IncomingFile;
    reader: Reader;
}
export declare class Reader {
    read(_fileInformation: FileInformation): Promise<File | void>;
    static testFileMimeType(_type: string): boolean;
    static testFileContent(_data: FileInformation): Promise<boolean>;
}
export declare function getFileReader(readers: Reader[], file: IncomingFile): Promise<Reader>;
export declare function getFileReaderByMimeType(readers: Reader[], type: string): Reader;
export declare function read({file, reader}: ReadParams): Promise<File>;
