"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var JSZip = require("jszip");
function getFileInformation(file) {
    return new Promise(function (resolve, reject) {
        if (typeof Buffer !== 'undefined' && file instanceof Buffer) {
            readFileBuffer(file);
        }
        else if ((typeof File !== 'undefined' && file instanceof File) ||
            (typeof Blob !== 'undefined' && file instanceof Blob)) {
            var reader_1 = new FileReader();
            reader_1.onload = function () { return readFileBuffer(reader_1.result); };
            reader_1.onerror = reject;
            reader_1.readAsArrayBuffer(file);
        }
        else {
            reject(new Error('The incoming file should be Buffer|Blob|File type'));
        }
        function readFileBuffer(fileBuffer) {
            var fileContent = (fileBuffer instanceof ArrayBuffer ? new Uint8Array(fileBuffer) : fileBuffer);
            resolve({
                fileBuffer: fileBuffer,
                fileContent: fileContent
            });
        }
    });
}
var File = (function () {
    function File(props) {
        this.meta = props.meta;
        this.media = props.media;
        this.content = props.content;
    }
    return File;
}());
exports.File = File;
function readArchive(fileContent) {
    return new JSZip().loadAsync(fileContent);
}
exports.readArchive = readArchive;
var Reader = (function () {
    function Reader() {
    }
    Reader.prototype.read = function (_fileInformation) {
        return Promise.reject(new Error('Invalid file'));
    };
    Reader.testFileMimeType = function (_type) {
        return false;
    };
    Reader.testFileContent = function (_data) {
        return Promise.resolve(false);
    };
    return Reader;
}());
exports.Reader = Reader;
function getFileReader(readers, file) {
    return new Promise(function (resolve, reject) {
        return getFileInformation(file).then(function (fileInformation) {
            var length = readers.length;
            var finishedPromisesCount = 0;
            var found = false;
            readers.forEach(function (reader) {
                reader.testFileContent(fileInformation).catch(function () {
                    // ignore the error
                    return false;
                }).then(function (result) {
                    finishedPromisesCount++;
                    if (!found && result) {
                        found = true;
                        return resolve(reader);
                    }
                    if (!found && finishedPromisesCount === length) {
                        resolve();
                    }
                });
            });
        }, reject);
    });
}
exports.getFileReader = getFileReader;
function getFileReaderByMimeType(readers, type) {
    return readers.find(function (reader) { return reader.testFileMimeType(type); });
}
exports.getFileReaderByMimeType = getFileReaderByMimeType;
function read(_a) {
    var file = _a.file, reader = _a.reader;
    if (!reader) {
        return Promise.reject(new Error('File Reader is not defined'));
    }
    return getFileInformation(file).then(function (fileInformation) {
        return reader.read(fileInformation);
    });
}
exports.read = read;
